@@ -21,11 +21,11 @@ __all__ = (
     "BackgroundSystemModel",
     "ExportInventory",
     "InternalNoiseModel",
-    "create_fleet_composition_from_REMIND_file",
+    "create_fleet_composition_from_IAM_file",
     "extract_electricity_mix_from_IAM_file",
     "extract_biofuel_shares_from_IAM"
 )
-__version__ = (1, 3, 7)
+__version__ = (1, 4, 0)
 
 from pathlib import Path
 
@@ -45,5 +45,5 @@ from .model import CarModel
 from .inventory import InventoryCalculation
 from .background_systems import BackgroundSystemModel
 from .export import ExportInventory
-from .utils import (create_fleet_composition_from_REMIND_file, extract_electricity_mix_from_IAM_file,
+from .utils import (create_fleet_composition_from_IAM_file, extract_electricity_mix_from_IAM_file,
                     extract_biofuel_shares_from_IAM)
