@@ -298,7 +298,8 @@ class ExportInventory:
                     new_val[0] = new_val[0].replace(key, d_names[key])
                     self.indices[k] = tuple(new_val)
 
-    def load_tags(self):
+    @staticmethod
+    def load_tags():
         """Loads dictionary of tags for further use in BW2"""
 
         filename = "tags.csv"
@@ -320,7 +321,8 @@ class ExportInventory:
 
         return dict_tags
 
-    def load_mapping_36_to_uvek(self):
+    @staticmethod
+    def load_mapping_36_to_uvek():
         """Load mapping dictionary between ecoinvent 3.6 and UVEK"""
 
         # Load the matching dictionary between ecoinvent and Simapro biosphere flows
@@ -342,7 +344,8 @@ class ExportInventory:
             dict_uvek[(name, ref_prod, unit, location)] = (uvek_name, uvek_ref_prod, uvek_unit, uvek_loc)
         return dict_uvek
 
-    def load_mapping_36_to_uvek_for_simapro(self):
+    @staticmethod
+    def load_mapping_36_to_uvek_for_simapro():
         """Load mapping dictionary between ecoinvent 3.6 and UVEK for Simapro name format"""
 
         # Load the matching dictionary between ecoinvent and Simapro biosphere flows
@@ -612,7 +615,7 @@ class ExportInventory:
 
                 else:
                     # Uncertainty
-                    if presamples == True:
+                    if presamples:
                         # Generate pre-sampled values
                         amount = np.median(self.array[:, row, col])  * mult_factor
                         uncertainty = [("uncertainty type", 1)]
@@ -696,7 +699,10 @@ class ExportInventory:
                 special_remark = self.references[tuple_output[0]]["special remark"]
             else:
 
-                key = [k for k in self.references.keys() if k.lower() in tuple_output[0].lower()][0]
+                try:
+                    key = [k for k in self.references.keys() if k.lower() in tuple_output[0].lower()][0]
+                except IndexError:
+                    print(tuple_output[0])
                 source = self.references[key]["source"]
                 description = self.references[key]["description"]
                 special_remark = self.references[key]["special remark"]
@@ -760,28 +766,43 @@ class ExportInventory:
                     if len(l) == 6:
                         _, _, pwt, size, year, _ = [t.strip() for t in tuple_output[0].split(",")]
                     else:
-                        if [t.strip() for t in tuple_output[0].split(",")][2] == "fleet average":
-                            _, _, _, pwt, year = [t.strip() for t in tuple_output[0].split(",")]
-                            size = "Medium"
+                        items = [t.strip() for t in tuple_output[0].split(",")]
+                        if items[2] == "fleet average":
+
+                            if items[3] == "all powertrains":
+                                size = None
+                                pwt = "diesel"
+
+                            else:
+                                _, _, _, pwt, year = [t.strip() for t in tuple_output[0].split(",")]
+                                size = "Medium"
                         else:
                             _, pwt, size, year, _ = [t.strip() for t in tuple_output[0].split(",")]
 
                     pwt = d_pwt[pwt]
 
-                    if not vehicle_specs is None:
-                        for p in vehicle_specs.parameter.values:
+                    if not size is None:
 
-                            val = vehicle_specs.sel(powertrain=pwt, size=size, year=int(year), value=0, parameter=p).values
+                        if not vehicle_specs is None:
 
-                            if val != 0:
+                            for p in vehicle_specs.parameter.values:
 
-                                if p in ("TtW efficiency", 'combustion power share',
-                                         'capacity utilization', 'fuel cell system efficiency'):
-                                    val = int(val * 100)
-                                else:
-                                    val = int(val)
+                                try:
+                                    val = vehicle_specs.sel(powertrain=pwt, size=size, year=int(year), value=0, parameter=p).values
 
-                                string += d_names[p] + ": " + str(val) + " " + d_units[p] + ". "
+                                    if val != 0:
+
+                                        if p in ("TtW efficiency", 'combustion power share',
+                                                 'capacity utilization', 'fuel cell system efficiency'):
+                                            val = int(val * 100)
+                                        else:
+                                            val = int(val)
+
+                                        string += d_names[p] + ": " + str(val) + " " + d_units[p] + ". "
+                                except KeyError:
+                                    print(f"Could not find vehicle specs for {pwt} {size} {year}")
+                    else:
+                        string = "Fleet average vehicle, all sizes and powertrains considered."
 
 
                 # Added transport distances if the inventory
@@ -907,7 +928,7 @@ class ExportInventory:
                     }
                 )
         if presamples:
-            return (list_act, presamples_matrix)
+            return list_act, presamples_matrix
         else:
             return list_act
 
@@ -927,6 +948,10 @@ class ExportInventory:
         Alternatively, exports a string representation of the file (in case the invenotry should be downloaded
         from a browser, for example)
 
+        :param vehicle_specs:
+        :param filename:
+        :param forbidden_activities:
+        :param export_format:
         :param directory: str. path to export the file to.
         :type directory: str or pathlib.Path
         :param ecoinvent_compatibility: bool. If True, the inventory is compatible with ecoinvent. If False, the inventory is compatible with REMIND-ecoinvent.
@@ -935,9 +960,7 @@ class ExportInventory:
         :type ecoinvent_version: str
         :param software_compatibility: str. "brightway2" or "simapro"
         :type software_compatibility: str
-        :param format: can be "file" or "string". If "file", returns a file path where the file is stored.
         If "string", returns a string.
-        :type format: str
         :returns: returns the file path of the exported inventory.
         :rtype: str.
         """
@@ -1038,7 +1061,6 @@ class ExportInventory:
                 return output.read()
 
         else:
-
             if export_format == "file":
                 with open(filepath_export, "w", newline="", encoding='latin1') as csvFile:
                     writer = csv.writer(csvFile, delimiter=";")
@@ -1057,7 +1079,8 @@ class ExportInventory:
                 csvFile.seek(0)
                 return csvFile.read()
 
-    def get_simapro_biosphere(self):
+    @staticmethod
+    def get_simapro_biosphere():
 
         # Load the matching dictionary between ecoinvent and Simapro biosphere flows
         filename = "simapro-biosphere.json"
@@ -1074,7 +1097,8 @@ class ExportInventory:
 
         return dict_bio
 
-    def get_simapro_technosphere(self):
+    @staticmethod
+    def get_simapro_technosphere():
 
         # Load the matching dictionary between ecoinvent and Simapro product flows
         filename = "simapro-technosphere-3.5.csv"
@@ -1089,7 +1113,7 @@ class ExportInventory:
         for row in data:
             name, location, simapro_name = row
             simapro_name = simapro_name.split("|")[:2]
-            dict_tech[(name, location)] = ("|").join(simapro_name)
+            dict_tech[(name, location)] = "|".join(simapro_name)
 
         return dict_tech
 
@@ -1370,10 +1394,10 @@ class ExportInventory:
                 if item == "External documents":
                     rows.append(["https://carculator.psi.ch"])
 
-                if item in ("System description"):
+                if item in "System description":
                     rows.append(["carculator"])
 
-                if item in ("Allocation rules"):
+                if item in "Allocation rules":
                     rows.append(
                         ["In the instance of joint-production, allocation of process burden based on"
                          "economic relative revenue of each co-product."])
@@ -1530,7 +1554,8 @@ class ExportInventory:
                                                          "tyre wear emissions",
                                                          "road wear emissions",
                                                          "used powertrain from electric passenger car"
-                                                         ]):
+                                                         ])\
+                                        or ("municipal solid waste, incineration" in e["name"] and e["unit"]=="kilowatt hour"):
 
                                     if e["name"] not in [i["name"] for i in data]:
 
@@ -1614,9 +1639,25 @@ class ExportInventory:
                         if (
                                 e["type"] == "biosphere"
                                 and e["categories"][0] == "air"
-                        ):
+                        ) or e["name"] in ["Carbon dioxide, from soil or biomass stock",
+                                           "Carbon dioxide, to soil or biomass stock"]:
                             if e["name"] not in simapro_biosphere_flows_to_remove:
-                                try:
+
+                                if e["name"] in ["Carbon dioxide, to soil or biomass stock"]:
+                                    rows.append(
+                                        [
+                                            dict_bio.get(e["name"], e["name"]),
+                                            "",
+                                            simapro_units[e["unit"]],
+                                            "{:.3E}".format(e["amount"] * -1),
+                                            "undefined",
+                                            0,
+                                            0,
+                                            0,
+                                        ]
+                                    )
+
+                                else:
                                     rows.append(
                                         [
                                             dict_bio.get(e["name"], e["name"]),
@@ -1629,8 +1670,6 @@ class ExportInventory:
                                             0,
                                         ]
                                     )
-                                except:
-                                    print(e["name"], e["categories"])
 
                 if item == "Emissions to water":
                     for e in a["exchanges"]:
@@ -1661,7 +1700,8 @@ class ExportInventory:
                         if (
                                 e["type"] == "biosphere"
                                 and e["categories"][0] == "soil"
-                        ):
+                        ) and e["name"] not in ["Carbon dioxide, from soil or biomass stock",
+                                                "Carbon dioxide, to soil or biomass stock"]:
                             if e["name"] not in simapro_biosphere_flows_to_remove:
                                 rows.append(
                                     [
@@ -1695,7 +1735,8 @@ class ExportInventory:
                                                  "used passenger car",
                                                  "used electric passenger car",
                                                  "municipal solid waste",
-                                                 "disposal")
+                                                 "disposal",
+                                                 "rainwater mineral oil")
                                        ) \
                                         and not any(i.lower() in e["name"].lower()
                                                     for i in ("anaerobic",
@@ -1703,8 +1744,7 @@ class ExportInventory:
                                                               "heat",
                                                               "manual dismantling"
                                                               ))\
-                                        and not any(i.lower() in e["reference product"].lower()
-                                                    for i in ["electricity"]):
+                                        and e["unit"] not in ["kilowatt hour", "megajoule"]:
                                     is_waste = True
 
                             # Yes, it is a waste treatment activity
@@ -1865,7 +1905,7 @@ class ExportInventory:
         :return: LCIImporter object to be imported in a Brightway2 project
         :rtype: bw2io.base_lci.LCIImporter
         """
-        if presamples == True:
+        if presamples:
             data, array = self.write_lci(
                 presamples=presamples,
                 ecoinvent_compatibility=ecoinvent_compatibility,
@@ -1875,7 +1915,7 @@ class ExportInventory:
             )
             i = bw2io.importers.base_lci.LCIImporter(self.db_name)
             i.data = data
-            return (i, array)
+            return i, array
         else:
             data = self.write_lci(
                 presamples=presamples,
